import * as echarts from 'echarts';
import React, { useEffect, useRef } from 'react'

type Props = {
    data: string[]
}

export default function lineCharts({
    data
}: Props) {

    const chartRef = useRef(null);

    useEffect(() => {
        const chart = echarts.init(chartRef.current!);
        const option = {
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'cross',
                    label: {
                        backgroundColor: '#6a7985'
                    }
                }
            },
            grid: {
                left: '3%',
                right: '0%',
                top: '15%',
                bottom: '15%',
                containLabel: true
            },
            xAxis: [
                {
                    type: 'category',
                    boundaryGap: false,
                    data: data,
                    axisLine: {
                        show: false,
                    },
                    axisLabel: {
                        fontSize: 16,
                        fontWeight: 400,
                        alignMinLabel: 'left',
                        alignMaxLabel: 'right',
                        interval: (index: number) => {
                            return index === 0 || index === data.length - 1;
                        },
                    },
                }
            ],
            yAxis: [
                {
                    type: 'value',
                    name: '单位：件',
                    nameTextStyle: {
                        color: '#BCCEE9',
                        fontSize: 14,
                        fontWeight: 400
                    },
                    splitLine: {
                        show: false
                    },
                    axisLine: {
                        show: false
                    },
                    axisLabel: {
                        show: false
                    }
                }
            ],
            series: [
                {
                    name: '案件数量',
                    type: 'line',
                    stack: 'Total',
                    smooth: true,
                    lineStyle: {
                        color: '#01FFF6'
                    },
                    itemStyle: {
                        color: '#01FFF6'
                    },
                    showSymbol: false,
                    areaStyle: {
                        opacity: 0.24,
                        color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                            {
                                offset: 0,
                                color: '#88EEF8'
                            },
                            {
                                offset: 1,
                                color: 'rgba(136, 238, 248, 0)'
                            }
                        ])
                    },
                    // 随机生成30个数字类型数据
                    data: Array.from({ length: 30 }, () =>
                        Math.floor(Math.random() * 1000)
                    )
                },
            ]
        };
        chart.setOption(option);

        return () => chart.dispose(); // 组件卸载时销毁
    }, [data]);

    return (
        <div ref={chartRef} style={{ width: '100%', height: 200, marginTop: 16 }} />
    )
}