import classNames from 'classnames'
import React, { CSSProperties, useEffect, useMemo } from 'react'

import LineCharts from './LineCharts';
import HncyCard from '@/pages/Home_v_2504/components/common/Card'
import DescriptionItem from '@/components/DescriptionItem'
import bgIcon1 from '@/assets/images/bgIcon1.png'
import bgIcon2 from '@/assets/images/bgIcon2.png'
import bgIcon3 from '@/assets/images/bgIcon3.png'
import bgIcon4 from '@/assets/images/bgIcon4.png'
import bgIcon5 from '@/assets/images/bgIcon5.png'

import styles from './index.less'

type statisticProps = {
    value: number;
    name: string;
    unit: string;
    bgIcon: string;
    iconSize: string;
    valueStyle?: CSSProperties;
    unitStyle?: CSSProperties;
    labelStyle?: CSSProperties;
    direction?: 'vertical' | 'horizontal';
}[]

export default function MiddleContent() {

    const statistic: statisticProps = useMemo(() => {
        return [
            {
                value: 1000,
                name: '立案',
                unit: '件',
                bgIcon: bgIcon1,
                iconSize: '46px 52px',
                valueStyle: valueStyle,
                unitStyle: unitStyle,
                labelStyle: labelStyle,
                direction: 'vertical',
            }, {
                value: 1000,
                name: '处置中',
                unit: '件',
                bgIcon: bgIcon2,
                iconSize: '44px 50px',
                valueStyle: {
                    ...valueStyle,
                    background: 'linear-gradient(180.00deg, rgb(170, 255, 246),rgb(10, 192, 167))',
                    // @ts-ignore
                    webkitBackgroundClip: 'text',
                    WebkitTextFillColor: 'transparent',
                    backgroundClip: 'text',
                    textFillColor: 'transparent',
                },
                unitStyle: unitStyle,
                labelStyle: labelStyle,
                direction: 'vertical'
            }, {
                value: 1000,
                name: '超时',
                unit: '件',
                bgIcon: bgIcon3,
                iconSize: '52px 52px',
                valueStyle: {
                    ...valueStyle,
                    color: '#FF4F4F',
                },
                unitStyle: unitStyle,
                labelStyle: labelStyle,
                direction: 'vertical'
            }, {
                value: 1000,
                name: '已办结',
                unit: '件',
                bgIcon: bgIcon4,
                iconSize: '48px 48px',
                valueStyle: valueStyle,
                unitStyle: unitStyle,
                labelStyle: {
                    ...labelStyle,
                    marginRight: 30
                },
                direction: 'horizontal'
            }, {
                value: 88.76,
                name: '办结率',
                unit: '%',
                bgIcon: bgIcon5,
                iconSize: '49px 49px',
                valueStyle: valueStyle,
                unitStyle: unitStyle,
                labelStyle: {
                    ...labelStyle,
                    marginRight: 30
                },
                direction: 'horizontal'
            },
        ]
    }, [])



    useEffect(() => {

    }, [])

    return (
        <div className={styles.middleContent}>
            <div className={styles.statistic}>
                {
                    statistic.map(({ bgIcon, iconSize, ...rest }, index) => {
                        return (
                            <div
                                key={index}
                                className={classNames(styles.statistic_item, index > 2 && styles.sp)}
                                style={{
                                    backgroundImage: `url(${bgIcon})`,
                                    backgroundSize: iconSize,
                                    backgroundRepeat: 'no-repeat',
                                    backgroundPosition: '100%',
                                }}
                            >
                                <DescriptionItem {...rest} decimals={index === statistic.length - 1 ? 2 : 0} />
                            </div>
                        )
                    })
                }
            </div>
            <div className={styles.line_chart}>
                <HncyCard
                    title='案件趋势'
                    style={{
                        width: '100%',
                        height: 224
                    }}
                >
                    <LineCharts data={['1月1日', '1月2日', '1月3日', '1月4日', '1月5日', '1月6日', '1月7日', '1月8日', '1月9日', '1月10日', '1月11日', '1月12日', '1月13日', '1月14日', '1月15日', '1月16日', '1月17日', '1月18日', '1月19日', '1月20日', '1月21日', '1月22日', '1月23日', '1月24日', '1月25日', '1月26日', '1月27日', '1月28日', '1月29日', '1月30日', '1月31日']} />
                </HncyCard>
            </div>
        </div>
    )
}

const valueStyle: CSSProperties = {
    fontSize: 28,
    fontWeight: 700,
    lineHeight: '26px',
}

const unitStyle: CSSProperties = {
    fontSize: 16,
    fontWeight: 400,
    lineHeight: '21px',
}

const labelStyle: CSSProperties = {
    fontSize: 16,
    fontWeight: 400,
    lineHeight: '21px',
}